# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalStudies(BaseModel):
    delete_medical_studies: Optional[
        List[Optional["DeleteMedicalStudiesDeleteMedicalStudies"]]
    ] = Field(alias="deleteMedicalStudies")


class DeleteMedicalStudiesDeleteMedicalStudies(BaseModel):
    id: str
    state: EntityState


DeleteMedicalStudies.model_rebuild()
