# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMedicalProcedures(BaseModel):
    medical_procedures: Optional["QueryMedicalProceduresMedicalProcedures"] = Field(
        alias="medicalProcedures"
    )


class QueryMedicalProceduresMedicalProcedures(BaseModel):
    results: Optional[List[Optional["QueryMedicalProceduresMedicalProceduresResults"]]]


class QueryMedicalProceduresMedicalProceduresResults(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    thing: Optional[str]
    relevance: Optional[float]


QueryMedicalProcedures.model_rebuild()
QueryMedicalProceduresMedicalProcedures.model_rebuild()
